Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Q in Connect.

Actions, resources, and condition keys for Amazon Q in Connect - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Q in Connect

Amazon Q in Connect (service prefix: `wisdom` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Q in Connect
- Resource types defined by Amazon Q in Connect
- Condition keys for Amazon Q in Connect

## Actions defined by Amazon Q in Connect

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateAssistant | Grants permission to create an assistant | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateAssistantAssociation | Grants permission to create an association between an assistant and another resource | Write | Assistant* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateContent | Grants permission to create content | Write | KnowledgeBase* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateKnowledgeBase | Grants permission to create a knowledge base | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateQuickResponse | Grants permission to create quick response | Write | KnowledgeBase* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateSession | Grants permission to create a session | Write | Assistant* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteAssistant | Grants permission to delete an assistant | Write | Assistant* |  |
DeleteAssistantAssociation | Grants permission to delete an assistant association | Write | Assistant* |  |
AssistantAssociation* |  |
DeleteContent | Grants permission to delete content | Write | Content* |  |
KnowledgeBase* |  |
DeleteImportJob | Grants permission to delete a import job of a knowledge base | Write | KnowledgeBase* |  |
DeleteKnowledgeBase | Grants permission to delete a knowledge base | Write | KnowledgeBase* |  |
DeleteQuickResponse | Grants permission to delete quick response | Write | KnowledgeBase* |  |
QuickResponse* |  |
GetAssistant | Grants permission to retrieve information about an assistant | Read | Assistant* |  |
GetAssistantAssociation | Grants permission to retrieve information about an assistant association | Read | Assistant* |  |
AssistantAssociation* |  |
GetContent | Grants permission to retrieve content, including a pre-signed URL to download the content | Read | Content* |  |
KnowledgeBase* |  |
GetContentSummary | Grants permission to retrieve summary information about the content | Read | Content* |  |
KnowledgeBase* |  |
GetImportJob | Grants permission to retrieve information about the import job | Read | KnowledgeBase* |  |
GetKnowledgeBase | Grants permission to retrieve information about the knowledge base | Read | KnowledgeBase* |  |
GetQuickResponse | Grants permission to retrieve content | Read | KnowledgeBase* |  |
QuickResponse* |  |
GetRecommendations | Grants permission to retrieve recommendations for the specified session | Read | Assistant* |  |
GetSession | Grants permission to retrieve information for a specified session | Read | Assistant* |  |
Session* |  |
ListAssistantAssociations | Grants permission to list information about assistant associations | List | Assistant* |  |
ListAssistants | Grants permission to list information about assistants | List |  |  |
ListContents | Grants permission to list the content with a knowledge base | List | KnowledgeBase* |  |
ListImportJobs | Grants permission to list information about knowledge bases | List | KnowledgeBase* |  |
ListKnowledgeBases | Grants permission to list information about knowledge bases | List |  |  |
ListQuickResponses | Grants permission to list the quick response with a knowledge base | List | KnowledgeBase* |  |
ListTagsForResource | Grants permission to list the tags for the specified resource | Read |  |  |
NotifyRecommendationsReceived | Grants permission to remove the specified recommendations from the specified assistant's queue of newly available recommendations | Write | Assistant* |  |
PutFeedback | Grants permission to submit feedback | Write | Assistant* |  |
QueryAssistant | Grants permission to perform a manual search against the specified assistant | Read | Assistant* |  |
RemoveKnowledgeBaseTemplateUri | Grants permission to remove a URI template from a knowledge base | Write | KnowledgeBase* |  |
SearchContent | Grants permission to search for content referencing a specified knowledge base. Can be used to get a specific content resource by its name | Read | KnowledgeBase* |  |
SearchQuickResponses | Grants permission to search for quick response referencing a specified knowledge base | Read | KnowledgeBase* |  | wisdom:GetQuickResponse
| wisdom:SearchFilter/RoutingProfileArn |
SearchSessions | Grants permission to search for sessions referencing a specified assistant. Can be used to et a specific session resource by its name | Read | Assistant* |  |
StartContentUpload | Grants permission to get a URL to upload content to a knowledge base | Write | KnowledgeBase* |  |
StartImportJob | Grants permission to create multiple quick responses | Write | KnowledgeBase* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TagResource | Grants permission to add the specified tags to the specified resource | Tagging | Assistant |  |
AssistantAssociation |  |
Content |  |
KnowledgeBase |  |
QuickResponse |  |
Session |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to remove the specified tags from the specified resource | Tagging | Assistant |  |
AssistantAssociation |  |
Content |  |
KnowledgeBase |  |
QuickResponse |  |
Session |  |
| aws:TagKeys aws:ResourceTag/${TagKey} |
UpdateContent | Grants permission to update information about the content | Write | Content* |  |
KnowledgeBase* |  |
UpdateKnowledgeBaseTemplateUri | Grants permission to update the template URI of a knowledge base | Write | KnowledgeBase* |  |
UpdateQuickResponse | Grants permission to update information or content of the quick response | Write | KnowledgeBase* |  |
QuickResponse* |  |

## Resource types defined by Amazon Q in Connect

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Assistant | `arn:$ { Partition}:wisdom:$ { Region}:$ { Account}:assistant/$ { AssistantId}` | aws:ResourceTag/${TagKey}
AssistantAssociation | `arn:$ { Partition}:wisdom:$ { Region}:$ { Account}:association/$ { AssistantId}/$ { AssistantAssociationId}` | aws:ResourceTag/${TagKey}
Content | `arn:$ { Partition}:wisdom:$ { Region}:$ { Account}:content/$ { KnowledgeBaseId}/$ { ContentId}` | aws:ResourceTag/${TagKey}
KnowledgeBase | `arn:$ { Partition}:wisdom:$ { Region}:$ { Account}:knowledge-base/$ { KnowledgeBaseId}` | aws:ResourceTag/${TagKey}
Session | `arn:$ { Partition}:wisdom:$ { Region}:$ { Account}:session/$ { AssistantId}/$ { SessionId}` | aws:ResourceTag/${TagKey}
QuickResponse | `arn:$ { Partition}:wisdom:$ { Region}:$ { Account}:quick-response/$ { KnowledgeBaseId}/$ { QuickResponseId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Q in Connect

Amazon Q in Connect defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString
wisdom:SearchFilter/RoutingProfileArn | Filters access by the connect routing profile arn that is passed in the request | ARN

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.